==> style-o-matic-1.1.37.tgz: package/es/components/ToolTip/ToolTip.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import ReactDOM from "react-dom";
import { CoreComponent, getCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./ToolTip.css";

var ToolTip = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolTip, _CoreComponent);

  function ToolTip(props) {
    _classCallCheck(this, ToolTip);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _this.handleMouseEnter = function (e) {
      if (_this.node) {
        var _this$node$getBoundin = _this.node.getBoundingClientRect(),
            x = _this$node$getBoundin.x,
            width = _this$node$getBoundin.width,
            bottom = _this$node$getBoundin.bottom,
            height = _this$node$getBoundin.height;

        var leftOffset = x + width;
        var topOffset = bottom;
        topOffset -= height / 2;
        _this.setState({ topOffset: topOffset, leftOffset: leftOffset });
      }
    };

    _this.useParentNode = true;
    _this.state = {
      topOffset: 0,
      leftOffset: 0
    };
    return _this;
  }

  ToolTip.prototype.render = function render() {
    var _props = this.props,
        position = _props.position,
        sorceProps = _objectWithoutProperties(_props, ["position"]);

    var _getValidProps = getValidProps(sorceProps),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var offsetStyle = {
      top: this.state.topOffset + "px",
      left: this.state.leftOffset + "px"
    };
    var widgetClass = "ui-tooltip-widget ";
    if (position) {
      widgetClass += "ui-tooltip-" + position;
    } else {
      widgetClass += " ui-tooltip-top";
    }

    return React.createElement(
      Component,
      _extends({}, props, {
        ref: this.onSetRef,
        onMouseEnter: this.handleMouseEnter
      }),
      React.createElement(
        "div",
        { className: "ui-tooltip-wrapper" },
        React.createElement(
          "div",
          { className: widgetClass, style: offsetStyle },
          React.createElement(
            "div",
            { className: "ui-tooltip-content" },
            children
          )
        )
      )
    );
  };

  return ToolTip;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TOOLTIP,
  position: "right"
}), _temp);


export default ToolTip;

==> style-o-matic-1.2.0.tgz: package/es/components/ToolTip/ToolTip.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof components
 * @namespace ToolTip
 * @author Steven Jackson
 * @scss ../../scss/components/ToolTip
 * @example <div>
   <ToolTip position="right">Example Tooltip</ToolTip>
 </div>
 */
import React from "react";
import { CoreComponent, setCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./ToolTip.css";

var ToolTip = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolTip, _CoreComponent);

  function ToolTip() {
    _classCallCheck(this, ToolTip);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolTip.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        text = _getValidProps.text,
        position = _getValidProps.position,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var tipText = text || escape(children);
    return React.createElement(
      Component,
      { "data-ui-tooltip": tipText, "data-ui-tooltip-pos": position },
      children
    );
  };

  return ToolTip;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "span",
  uirole: ROLE.TOOLTIP,
  position: "top"
}), _temp);


export default ToolTip;
